package appmain;
/*
* This servlet produces a little snippet of text output, based on
* a list of razor manufacturers and an index supplied by the user.
*/
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Enumeration;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
/**
* Simple servlet.  This servlet expects to be given a parameter
* "index" which it then uses to look up a device name.  The 
* paramter is specified in the URL with .../apppath/device?index=n.
* For example: 
* http://cubist.cs.washington.edu:8080/djohnson/device?index=10
*/
public final class Razor extends HttpServlet {
	/**
	* Respond to a GET request for the content produced by
	* this servlet.
	*
	* @param request The servlet request we are processing
	* @param response The servlet response we are producing
	*
	* @exception IOException if an input/output error occurs
	* @exception ServletException if a servlet error occurs
	*/
	public void doGet(HttpServletRequest request, HttpServletResponse response)
	throws IOException, ServletException {
		
		String responseString;
		int index;
		
		String indexParam = request.getParameter("index");
		if (indexParam == null) {
			responseString = "no index supplied";
		} else {
			try {
				index = Integer.parseInt(indexParam);
				if ((index < 0) || (index >= devices.length)) {
					responseString = "index out of range";
				} else {
					responseString = devices[index];
				}
			}
			catch (NumberFormatException e) {
				responseString = "number format exception";
			}
		}
		
		response.setContentType("text/plain");
		PrintWriter writer = response.getWriter();
		writer.println(responseString);
	}
	
	//----------------------------------------------------------------
	
	private String[] devices = {
		"Gillette","Schick","Wilkinson","Remington",
		"Sheffield",
		"Dubl-Duck", "Lifetime", "Napoleon", "Beau Brummel", "Deutsch", "Satinedge"
	};
}
